==> aws-cdk-scala_2.12-0.5.1-sources.jar: io/burkard/cdk/services/kendra/cfnDataSource/SharePointConfigurationProperty.scala <==
package io.burkard.cdk.services.kendra.cfnDataSource

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object SharePointConfigurationProperty {

  def apply(
    urls: List[String],
    sharePointVersion: String,
    secretArn: String,
    disableLocalGroups: Option[Boolean] = None,
    exclusionPatterns: Option[List[String]] = None,
    documentTitleFieldName: Option[String] = None,
    fieldMappings: Option[List[_]] = None,
    sslCertificateS3Path: Option[software.amazon.awscdk.services.kendra.CfnDataSource.S3PathProperty] = None,
    vpcConfiguration: Option[software.amazon.awscdk.services.kendra.CfnDataSource.DataSourceVpcConfigurationProperty] = None,
    inclusionPatterns: Option[List[String]] = None,
    crawlAttachments: Option[Boolean] = None,
    useChangeLog: Option[Boolean] = None
  ): software.amazon.awscdk.services.kendra.CfnDataSource.SharePointConfigurationProperty =
    (new software.amazon.awscdk.services.kendra.CfnDataSource.SharePointConfigurationProperty.Builder)
      .urls(urls.asJava)
      .sharePointVersion(sharePointVersion)
      .secretArn(secretArn)
      .disableLocalGroups(disableLocalGroups.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .exclusionPatterns(exclusionPatterns.map(_.asJava).orNull)
      .documentTitleFieldName(documentTitleFieldName.orNull)
      .fieldMappings(fieldMappings.map(_.asJava).orNull)
      .sslCertificateS3Path(sslCertificateS3Path.orNull)
      .vpcConfiguration(vpcConfiguration.orNull)
      .inclusionPatterns(inclusionPatterns.map(_.asJava).orNull)
      .crawlAttachments(crawlAttachments.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .useChangeLog(useChangeLog.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .build()
}

==> aws-cdk-scala_2.13-0.20.0-sources.jar: io/burkard/cdk/services/kendra/cfnDataSource/SharePointConfigurationProperty.scala <==
package io.burkard.cdk.services.kendra.cfnDataSource

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object SharePointConfigurationProperty {

  def apply(
    urls: List[String],
    sharePointVersion: String,
    secretArn: String,
    disableLocalGroups: Option[Boolean] = None,
    exclusionPatterns: Option[List[String]] = None,
    documentTitleFieldName: Option[String] = None,
    fieldMappings: Option[List[_]] = None,
    sslCertificateS3Path: Option[software.amazon.awscdk.services.kendra.CfnDataSource.S3PathProperty] = None,
    vpcConfiguration: Option[software.amazon.awscdk.services.kendra.CfnDataSource.DataSourceVpcConfigurationProperty] = None,
    inclusionPatterns: Option[List[String]] = None,
    crawlAttachments: Option[Boolean] = None,
    useChangeLog: Option[Boolean] = None
  ): software.amazon.awscdk.services.kendra.CfnDataSource.SharePointConfigurationProperty =
    (new software.amazon.awscdk.services.kendra.CfnDataSource.SharePointConfigurationProperty.Builder)
      .urls(urls.asJava)
      .sharePointVersion(sharePointVersion)
      .secretArn(secretArn)
      .disableLocalGroups(disableLocalGroups.map(Boolean.box).orNull)
      .exclusionPatterns(exclusionPatterns.map(_.asJava).orNull)
      .documentTitleFieldName(documentTitleFieldName.orNull)
      .fieldMappings(fieldMappings.map(_.asJava).orNull)
      .sslCertificateS3Path(sslCertificateS3Path.orNull)
      .vpcConfiguration(vpcConfiguration.orNull)
      .inclusionPatterns(inclusionPatterns.map(_.asJava).orNull)
      .crawlAttachments(crawlAttachments.map(Boolean.box).orNull)
      .useChangeLog(useChangeLog.map(Boolean.box).orNull)
      .build()
}
